---
title: "This Year We Can End the Death Penalty in California"
date: "November 2016"
---

If you're a California voter, there is an important proposition on your ballot this year: Proposition 62, which bans the death penalty.

When I was younger I used to think the debate about the death penalty was about when it's ok to take a human life. Is it ok to kill a killer?

But that is not the issue here.

The real world does not work like the version I was shown on TV growing up. The police often arrest the wrong person. Defendants' lawyers are often incompetent. And prosecutors are often motivated more by publicity than justice.

In the real world, [about 4%](http://time.com/79572/more-innocent-people-on-death-row-than-estimated-study/) of people sentenced to death are innocent. So this is not about whether it's ok to kill killers. This is about whether it's ok to kill innocent people.

A child could answer that one for you.

This year, in California, you have a chance to end this, by voting yes on Proposition 62. But beware, because there is another proposition, Proposition 66, whose goal is to make it easier to execute people. So yes on 62, no on 66.

It's time.